@@ -1,5 +1,5 @@
 import struct
-from typing import Tuple, Optional
+from typing import Tuple, Dict
 from ..uuid import CLSID_SZ, bin_to_str
 from .class_part import ClassPart
 from .object_block import ObjectBlock
@@ -15,7 +15,7 @@ class WbemDatapacketObject:
     def from_data(
             data: bytes,
             offset: int,
-            class_part: Optional[ClassPart] = None) -> Tuple[WbemObject, int]:
+            class_parts: Dict[str, ClassPart]) -> Tuple[WbemObject, int]:
 
         (
             dw_size_of_header0,
@@ -31,11 +31,7 @@ class WbemDatapacketObject:
         clsid = bin_to_str(data, offset=offset)
         offset += CLSID_SZ
 
-        if b_object_type == 2:
-            # We have a class part, make sure class_part is None. Usually the
-            # class_part is None in this case, but it is not required so this
-            # code is important.
-            class_part = None
+        class_part = None if b_object_type == 2 else class_parts[clsid]
 
         # b_object_type == 2 means the data contains the class_part
         # b_object_type == 3 means we must already have a class_part
@@ -44,4 +40,9 @@ class WbemDatapacketObject:
             (b_object_type == 3 and class_part is not None)
         ), f'object type: {b_object_type} and class_part: {class_part}'
 
-        return ObjectBlock.from_data(data, offset, class_part)
+        obj_block, offset = ObjectBlock.from_data(data, offset, class_part)
+
+        if b_object_type == 2:
+            class_parts[clsid] = obj_block.class_part
+
+        return obj_block, offset
